@@ -51,4 +51,4 @@ for project in Project.NAME.value:
 
 # GitHub/Lab constants
 gitlab_function_name_addition = "FUNCTION_NAME_ADDITION"
-gitlab_ci_project = "CI_PROJECT_NAME"
+gitlab_ci_project = "CI_PROJECT_PATH"
